.. PETGEM documentation master file, created by
   sphinx-quickstart on Wed Dec 13 16:53:41 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

PETGEM documentation
====================

.. toctree::
   :maxdepth: 3

   WhatIs
   Features
   CSEMEdges
   Installation
   Tutorial
   Manual
   Publications
   Download
   Contact

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
